@@ -1,44 +1,41 @@
 from django import forms
 
-from django_helper_forms.forms import DictionaryFieldsForm
-
-import models
+from groups_manager import models
 
 
 class MemberForm(forms.ModelForm):
 
     class Meta:
         model = models.Member
+        exclude = set()
 
 
 class GroupTypeForm(forms.ModelForm):
 
     class Meta:
         model = models.GroupType
+        exclude = set()
 
 
 class GroupEntityForm(forms.ModelForm):
 
     class Meta:
         model = models.GroupEntity
+        exclude = set()
 
 
-class GroupForm(forms.ModelForm, DictionaryFieldsForm):
+class GroupForm(forms.ModelForm):
 
     class Meta:
         model = models.Group
         exclude = ('group_members', )
 
-    def __init__(self, *args, **kwargs):
-        super(GroupForm, self).__init__(*args, **kwargs)
-        self.dictionary_fields = ['properties', ]
-        self.format_dictionary_fields()
-
 
 class GroupMemberRoleForm(forms.ModelForm):
 
     class Meta:
         model = models.GroupMemberRole
+        exclude = set()
 
 
 class GroupMemberForm(forms.ModelForm):
@@ -54,6 +51,7 @@ class GroupMemberAddMemberForm(forms.ModelForm):
 
     class Meta:
         model = models.GroupMember
+        exclude = set()
 
 
 class GroupMemberAddGroupForm(forms.ModelForm):
@@ -62,3 +60,4 @@ class GroupMemberAddGroupForm(forms.ModelForm):
 
     class Meta:
         model = models.GroupMember
+        exclude = set()
